@@ -51,8 +51,15 @@ def save_env():
         json.dump(jqdata_env, outfile)
 
 
-from .api import *
+# the __all__ is generated
+__all__ = ['init_env', 'save_env']
 
-__all__ = ['run_query', 'get_all_securities', 'get_trade_days', 'get_fundamentals', 'get_mtss', 'get_all_trade_days',
-           'get_bars', 'get_token', 'request_jqdata', 'init_env', 'get_dominant_future', 'get_future_contracts',
-           'get_security_info']
+# __init__.py structure:
+# common code of the package
+# export interface in __all__ which contains __all__ of its sub modules
+
+# import all from submodule api
+from .api import *
+from .api import __all__ as _api_all
+
+__all__ += _api_all
