@@ -8,10 +8,6 @@ import requests
 
 from jqdatapy import jqdata_env, save_env
 
-__all__ = ['run_query', 'get_all_securities', 'get_trade_days', 'get_fundamentals', 'get_mtss', 'get_all_trade_days',
-           'get_bars', 'get_token', 'request_jqdata', 'get_dominant_future', 'get_future_contracts',
-           'get_security_info']
-
 url = "https://dataapi.joinquant.com/apis"
 
 
@@ -227,3 +223,8 @@ if __name__ == "__main__":
     # print(get_bars(code='AU9999.XSGE'))
     # print(get_security_info())
     print(get_price_period(end_date='2010-01-01'))
+
+# the __all__ is generated
+__all__ = ['HttpAccessError', 'run_query', 'get_future_contracts', 'get_security_info', 'get_dominant_future',
+           'get_all_securities', 'get_trade_days', 'get_fundamentals', 'get_mtss', 'get_all_trade_days', 'get_bars',
+           'get_price_period', 'get_bars_period', 'get_token', 'request_jqdata']
